==> designer-asset-1.0.10-20251124.131638-6-sources.jar: com/digiwin/athena/dao/mongodao/assetType/RAssetTypeMongoDao.java <==
package com.digiwin.athena.dao.mongodao.assetType;

import com.digiwin.athena.mongodb.domain.assetType.AssetType;
import com.digiwin.athena.mongodb.repository.MongoRuntimeRepositoryDecorator;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;

import java.util.List;

@Slf4j
@Repository
public class RAssetTypeMongoDao {

    @Autowired
    private MongoRuntimeRepositoryDecorator mongoRuntimeRepositoryDecorator;

    public void deleteById(String objId) {
        Criteria criteria = Criteria.where("_id").is(objId);
        mongoRuntimeRepositoryDecorator.delete(new Query(criteria),AssetType.class);
    }

    public void insert(AssetType assetType) {
        mongoRuntimeRepositoryDecorator.insert(assetType);
    }

    public AssetType selectById(String objId) {
        Criteria criteria = Criteria.where("_id").is(objId);
        return mongoRuntimeRepositoryDecorator.findOne(new Query(criteria), AssetType.class);
    }

    public void save(AssetType rAssetType) {
        mongoRuntimeRepositoryDecorator.save(rAssetType);
    }

    public List<AssetType> selectByStatus(String status) {
        Criteria criteria = Criteria.where("status").is(status);
        return mongoRuntimeRepositoryDecorator.find(new Query(criteria), AssetType.class);
    }

    public AssetType selectByType(String type) {
        Criteria criteria = Criteria.where("type").is(type);
        return mongoRuntimeRepositoryDecorator.findOne(new Query(criteria), AssetType.class);
    }
}

==> designer-asset-1.0.10-20251218.052049-68-sources.jar: com/digiwin/athena/dao/mongodao/assetType/RAssetTypeMongoDao.java <==
package com.digiwin.athena.dao.mongodao.assetType;

import com.digiwin.athena.mongodb.domain.assetType.AssetType;
import com.digiwin.athena.mongodb.repository.MongoRuntimeRepositoryDecorator;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;

@Slf4j
@Repository
public class RAssetTypeMongoDao {

    @Autowired
    private MongoRuntimeRepositoryDecorator mongoRuntimeRepositoryDecorator;

    public void deleteById(String objId) {
        Criteria criteria = Criteria.where("_id").is(objId);
        mongoRuntimeRepositoryDecorator.delete(new Query(criteria),AssetType.class);
    }

    public void insert(AssetType assetType) {
        mongoRuntimeRepositoryDecorator.insert(assetType);
    }

    public AssetType selectById(String objId) {
        Criteria criteria = Criteria.where("_id").is(objId);
        return mongoRuntimeRepositoryDecorator.findOne(new Query(criteria), AssetType.class);
    }

    public void save(AssetType rAssetType) {
        mongoRuntimeRepositoryDecorator.save(rAssetType);
    }

    public List<AssetType> selectByStatus(String status) {
        Criteria criteria = Criteria.where("status").is(status);
        return mongoRuntimeRepositoryDecorator.find(new Query(criteria), AssetType.class);
    }

    public AssetType selectByType(String type) {
        Criteria criteria = Criteria.where("type").is(type);
        return mongoRuntimeRepositoryDecorator.findOne(new Query(criteria), AssetType.class);
    }

    public List<AssetType> selectByIds(Collection<String> assetTypeIds) {
        Criteria criteria = Criteria.where("_id").in(assetTypeIds);
        return mongoRuntimeRepositoryDecorator.find(new Query(criteria), AssetType.class);
    }
}
